@@ -888,7 +888,7 @@ struct fuse_lowlevel_ops {
 	 */
 	void (*ioctl) (fuse_req_t req, fuse_ino_t ino, int cmd, void *arg,
 		       struct fuse_file_info *fi, unsigned flags,
-		       const void *in_buf, size_t in_bufsz, size_t out_bufsz);
+		       const void *in_buf, uint32_t in_bufsz, uint32_t out_bufsz);
 
 	/**
 	 * Poll for IO readiness
@@ -1021,6 +1021,52 @@ struct fuse_lowlevel_ops {
 	 */
 	void (*fallocate) (fuse_req_t req, fuse_ino_t ino, int mode,
 		       off_t offset, off_t length, struct fuse_file_info *fi);
+
+  /**
+   * Copy a range of data from one file to another
+   *
+   * Performs an optimized copy between two file descriptors without
+   * the
+   * additional cost of transferring data through the FUSE kernel
+   * module
+   * to user space (glibc) and then back into the FUSE filesystem
+   * again.
+   *
+   * In case this method is not implemented, glibc falls back to
+   * reading
+   * data from the source and writing to the destination. Effectively
+   * doing an inefficient copy of the data.
+   *
+   * If this request is answered with an error code of ENOSYS, this is
+   * treated as a permanent failure with error code EOPNOTSUPP,
+   * i.e. all
+   * future copy_file_range() requests will fail with EOPNOTSUPP
+   * without
+   * being send to the filesystem process.
+   *
+   * Valid replies:
+   *   fuse_reply_write
+   *   fuse_reply_err
+   *
+   * @param req request handle
+   * @param ino_in the inode number of the source file
+   * @param off_in starting point from were the data should be read
+   * @param fi_in file information of the source file
+   * @param ino_out the inode number of the destination file
+   * @param off_out starting point where the data should be written
+   * @param fi_out file information of the destination file
+   * @param len maximum size of the data to copy
+   * @param flags passed along with the copy_file_range() syscall
+   */
+  void (*copy_file_range)(fuse_req_t             req,
+                          fuse_ino_t             ino_in,
+                          off_t                  off_in,
+                          struct fuse_file_info *fi_in,
+                          fuse_ino_t             ino_out,
+                          off_t                  off_out,
+                          struct fuse_file_info *fi_out,
+                          size_t                 len,
+                          int                    flags);
 };
 
 /**
@@ -1286,7 +1332,7 @@ int fuse_reply_ioctl_retry(fuse_req_t req,
  * @param buf buffer containing output data
  * @param size length of output data
  */
-int fuse_reply_ioctl(fuse_req_t req, int result, const void *buf, size_t size);
+int fuse_reply_ioctl(fuse_req_t req, int result, const void *buf, uint32_t size);
 
 /**
  * Reply to finish ioctl with iov buffer
