@@ -14,8 +14,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __BUILDMAP_HPP__
-#define __BUILDMAP_HPP__
+#pragma once
 
 #include <algorithm>
 
@@ -44,5 +43,3 @@ public:
 private:
   std::map<K,V> _map;
 };
-
-#endif
