@@ -16,6 +16,8 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#pragma once
+
 #include <string>
 
 namespace fs
@@ -23,6 +25,6 @@ namespace fs
   namespace acl
   {
     bool
-    dir_has_defaults(const std::string &fullpath);
+    dir_has_defaults(const std::string &fullpath_);
   }
 }
