@@ -14,18 +14,15 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FS_BASE_FALLOCATE_HPP__
-#define __FS_BASE_FALLOCATE_HPP__
+#pragma once
 
 #include <fcntl.h>
 
 namespace fs
 {
   int
-  fallocate(const int   fd,
-            const int   mode,
-            const off_t offset,
-            const off_t len);
+  fallocate(const int   fd_,
+            const int   mode_,
+            const off_t offset_,
+            const off_t len_);
 }
-
-#endif
