@@ -29,19 +29,38 @@ namespace fs
   static
   inline
   int
-  open(const std::string &path,
-       const int          flags)
+  open(const char *path_,
+       const int   flags_)
   {
-    return ::open(path.c_str(),flags);
+    return ::open(path_,flags_);
   }
 
   static
   inline
   int
-  open(const std::string &path,
-       const int          flags,
-       const mode_t       mode)
+  open(const char   *path_,
+       const int     flags_,
+       const mode_t  mode_)
   {
-    return ::open(path.c_str(),flags,mode);
+    return ::open(path_,flags_,mode_);
+  }
+
+  static
+  inline
+  int
+  open(const std::string &path_,
+       const int          flags_)
+  {
+    return fs::open(path_.c_str(),flags_);
+  }
+
+  static
+  inline
+  int
+  open(const std::string &path_,
+       const int          flags_,
+       const mode_t       mode_)
+  {
+    return fs::open(path_.c_str(),flags_,mode_);
   }
 }
