@@ -28,9 +28,18 @@ namespace fs
   static
   inline
   int
-  truncate(const std::string &path,
-           const off_t        length)
+  truncate(const char  *path_,
+           const off_t  length_)
   {
-    return ::truncate(path.c_str(),length);
+    return ::truncate(path_,length_);
+  }
+
+  static
+  inline
+  int
+  truncate(const std::string &path_,
+           const off_t        length_)
+  {
+    return fs::truncate(path_.c_str(),length_);
   }
 }
