@@ -70,8 +70,7 @@ namespace fs
     if((relative == NULL) || (relative[0] == '\0'))
       return 0;
 
-    dirname = relative;
-    fs::path::dirname(dirname);
+    dirname = fs::path::dirname(relative);
     if(!dirname.empty())
       {
         rv = fs::clonepath(fromsrc,tosrc,dirname);
@@ -79,14 +78,14 @@ namespace fs
           return -1;
       }
 
-    fs::path::make(&fromsrc,relative,frompath);
-    rv = fs::stat(frompath,st);
+    frompath = fs::path::make(fromsrc,relative);
+    rv = fs::stat(frompath,&st);
     if(rv == -1)
       return -1;
     else if(!S_ISDIR(st.st_mode))
       return (errno=ENOTDIR,-1);
 
-    fs::path::make(&tosrc,relative,topath);
+    topath = fs::path::make(tosrc,relative);
     rv = fs::mkdir(topath,st.st_mode);
     if(rv == -1)
       {
@@ -118,10 +117,10 @@ namespace fs
   }
 
   int
-  clonepath(const std::string &from,
-            const std::string &to,
-            const std::string &relative,
-            const bool         return_metadata_errors)
+  clonepath(const string &from,
+            const string &to,
+            const string &relative,
+            const bool    return_metadata_errors)
   {
     return fs::clonepath(from,to,relative.c_str(),return_metadata_errors);
   }
@@ -145,10 +144,10 @@ namespace fs
   }
 
   int
-  clonepath_as_root(const std::string &from,
-                    const std::string &to,
-                    const std::string &relative,
-                    const bool         return_metadata_errors)
+  clonepath_as_root(const string &from,
+                    const string &to,
+                    const string &relative,
+                    const bool    return_metadata_errors)
   {
     return fs::clonepath_as_root(from,to,relative.c_str(),return_metadata_errors);
   }
