@@ -14,8 +14,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __FS_MOVEFILE_HPP__
-#define __FS_MOVEFILE_HPP__
+#pragma once
 
 #include <string>
 #include <vector>
@@ -27,12 +26,4 @@ namespace fs
            const std::string              &fusepath,
            const size_t                    additional_size,
            int                            &origfd);
-
-  int
-  movefile(const std::vector<std::string> &basepaths,
-           const char                     *fusepath,
-           const size_t                    additional_size,
-           int                            &origfd);
 }
-
-#endif
