@@ -14,27 +14,8 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#include <errno.h>
-
-#if defined __linux__
-#include <sys/sendfile.h>
-#endif
-
-#include "fs_sendfile.hpp"
-
-namespace fs
-{
-  ssize_t
-  sendfile(const int    fdin,
-           const int    fdout,
-           const size_t count)
-  {
-#if defined __linux__
-    off_t offset = 0;
-
-    return ::sendfile(fdout,fdin,&offset,count);
+#ifdef __linux__
+# include "fs_sendfile_linux.icpp"
 #else
-    return (errno=EINVAL,-1);
+# include "fs_sendfile_unsupported.icpp"
 #endif
-  }
-}
