@@ -14,32 +14,28 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#include "errno.hpp"
+#include "policy.hpp"
+
 #include <algorithm>
 #include <string>
 #include <vector>
 
-#include "errno.hpp"
-#include "policy.hpp"
-#include "success_fail.hpp"
-
 using std::string;
 using std::vector;
 
-namespace mergerfs
+int
+Policy::Func::eprand(const Category::Enum::Type  type,
+                     const Branches             &branches_,
+                     const char                 *fusepath,
+                     const uint64_t              minfreespace,
+                     vector<const string*>      &paths)
 {
-  int
-  Policy::Func::eprand(const Category::Enum::Type  type,
-                       const vector<string>       &basepaths,
-                       const char                 *fusepath,
-                       const uint64_t              minfreespace,
-                       vector<const string*>      &paths)
-  {
-    int rv;
+  int rv;
 
-    rv = Policy::Func::epall(type,basepaths,fusepath,minfreespace,paths);
-    if(POLICY_SUCCEEDED(rv))
-      std::random_shuffle(paths.begin(),paths.end());
+  rv = Policy::Func::epall(type,branches_,fusepath,minfreespace,paths);
+  if(rv == 0)
+    std::random_shuffle(paths.begin(),paths.end());
 
-    return rv;
-  }
+  return rv;
 }
