@@ -16,14 +16,11 @@
 
 #pragma once
 
-namespace mergerfs
+namespace resources
 {
-  namespace resources
-  {
-    int reset_umask(void);
-    int maxout_rlimit(const int resource);
-    int maxout_rlimit_nofile(void);
-    int maxout_rlimit_fsize(void);
-    int setpriority(const int prio);
-  }
+  int reset_umask(void);
+  int maxout_rlimit(const int resource_);
+  int maxout_rlimit_nofile(void);
+  int maxout_rlimit_fsize(void);
+  int setpriority(const int prio_);
 }
