@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016, Antonio SJ Musumeci <trapexit@spawn.link>
+  Copyright (c) 2019, Antonio SJ Musumeci <trapexit@spawn.link>
 
   Permission to use, copy, modify, and/or distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -18,10 +18,9 @@
 
 #include <string>
 
+#include <stdint.h>
 #include <sys/statvfs.h>
 
-#include "success_fail.hpp"
-
 namespace StatVFS
 {
   static
