@@ -14,21 +14,17 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#ifndef __UGID_HPP__
-#define __UGID_HPP__
+#pragma once
 
 #include <sys/types.h>
 #include <unistd.h>
 
 #include <vector>
 
-namespace mergerfs
+namespace ugid
 {
-  namespace ugid
-  {
-    void init();
-    void initgroups(const uid_t uid, const gid_t gid);
-  }
+  void init();
+  void initgroups(const uid_t uid, const gid_t gid);
 }
 
 #if defined __linux__ and UGID_USE_RWLOCK == 0
@@ -36,5 +32,3 @@ namespace mergerfs
 #else
 #include "ugid_rwlock.hpp"
 #endif
-
-#endif
